# AutoFac

AutoFac is a library that allows you to use Dependency Inversion Principle in Python.

## Python environment

Create your python environment using `poetry install -E all`

## Adding documentation

1. Run `mkdocs new .` to create the documentation structure (after customizing template)
2. Change theme in `mkdocs.yml` to `material`

### Useful resources

1. [Material for MkDocs](https://jamstackthemes.dev/demo/theme/mkdocs-material/)
2. [MkDocs](https://www.mkdocs.org/)
3. [Blog post](https://blog.elmah.io/creating-a-documentation-site-with-mkdocs/)
